@@ -1,19 +1,18 @@
-from copy import deepcopy
 import logging
-from typing import Optional, Union, Tuple, Iterable
+from copy import deepcopy
+from typing import Iterable, Optional, Tuple, Union
 
+import matplotlib.pyplot as plt
 import numpy as np
 from matplotlib import path
-import matplotlib.pyplot as plt
 from scipy import interpolate
-from shapely import geometry as geo
 from shapely import affinity
+from shapely import geometry as geo
 from shapely.validation import explain_validity
 
 from ..geometry import close_curve
 from ..parameter import Parameter
-from .mesh import generate_mesh, optimize_mesh
-
+from .mesh import generate_mesh, smooth_mesh
 
 logger = logging.getLogger(__name__)
 
@@ -29,6 +28,8 @@ class Layer:
 
     Args:
         name: Name of the layer.
+        Lambda: The effective magnetic penetration depth of the superconducting
+            film(s) in the layer.
         thickness: Thickness of the superconducting film(s) located in the layer.
         london_lambda: London penetration depth of the superconducting film(s)
             located in the layer.
@@ -265,10 +266,7 @@ class Polygon:
     def make_mesh(
         self,
         min_points: Optional[int] = None,
-        optimesh_steps: Optional[int] = None,
-        optimesh_method: str = "cvt-block-diagonal",
-        optimesh_tolerance: float = 1e-3,
-        optimesh_verbose: bool = False,
+        smooth: int = 0,
         **meshpy_kwargs,
     ) -> Tuple[np.ndarray, np.ndarray]:
         """Returns the vertices and triangles of a Delaunay mesh covering the Polygon.
@@ -277,11 +275,7 @@ class Polygon:
             min_points: Minimum number of vertices in the mesh. If None, then
                 the number of vertices will be determined by meshpy_kwargs and the
                 number of vertices in the underlying polygons.
-            optimesh_steps: Maximum number of optimesh steps. If None, then no
-                optimization is done.
-            optimesh_method: Name of the optimization method to use.
-            optimesh_tolerance: Optimesh quality tolerance.
-            optimesh_verbose: Whether to use verbose mode in optimesh.
+            smooth: Number of Laplacian smoothing steps to perform.
             **meshpy_kwargs: Passed to meshpy.triangle.build().
 
         Returns:
@@ -293,23 +287,9 @@ class Polygon:
             convex_hull=False,
             **meshpy_kwargs,
         )
-        if optimesh_steps:
+        if smooth:
             logger.debug(f"Optimizing mesh with {points.shape[0]} vertices.")
-            try:
-                points, triangles = optimize_mesh(
-                    points,
-                    triangles,
-                    optimesh_steps,
-                    method=optimesh_method,
-                    tolerance=optimesh_tolerance,
-                    verbose=optimesh_verbose,
-                )
-            except np.linalg.LinAlgError as e:
-                err = (
-                    "LinAlgError encountered in optimesh. Try reducing min_points "
-                    "or increasing the number of points in the Polygon."
-                )
-                raise RuntimeError(err) from e
+            points, triangles = smooth_mesh(points, triangles, smooth)
         logger.debug(
             f"Finished generating mesh with {points.shape[0]} points and "
             f"{triangles.shape[0]} triangles."
@@ -567,6 +547,7 @@ class Polygon:
 
 
         Args:
+            distance: The amount by which to inflate or deflate the polygon.
             join_style: One of "round" (1), "mitre" (2), or "bevel" (3).
                 See the `shapely documentation`_.
             mitre_limit: See the `shapely documentation`_.
@@ -613,6 +594,7 @@ class Polygon:
                 then an unaltered copy of the polygon is returned.
             degree: The degree of the spline with which to iterpolate.
                 Defaults to 1 (linear spline).
+            smooth: Smoothing condition.
 
         """
         if num_points is None:
